@@ -110,22 +110,28 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         dirFileText = dirFileText.replace('%%name%%',  self.inpEditName.text())
         dirFileText = dirFileText.replace('%%icon%%',  self.inpIcon.text())
         
-        f = open(dirFileName, 'w')
-        f.write(dirFileText)
-        f.close()
-
-        if isNew:
+        if not os.path.exists(self.mainApp.folderlist.Menupath):
+            os.makedirs(self.mainApp.folderlist.Menupath)
         
-            menuFileText = self.mainApp.readMenuTemplate()
-            menuFileText = menuFileText.replace('%%name%%',  self.inpEditName.text())
-            menuFileText = menuFileText.replace('%%path%%',  folderName)
-            
-            menuFileName = self.mainApp.folderlist.Menupath + folderName + ".menu"
-            f = open(menuFileName, 'w')
-            f.write(menuFileText)
+        try:
+            f = open(dirFileName, 'w')
+            f.write(dirFileText)
             f.close()
-        
-        self.mainApp.showInfoPopup(self, "Your folder was successfully saved!")
+
+            if isNew:
+            
+                menuFileText = self.mainApp.readMenuTemplate()
+                menuFileText = menuFileText.replace('%%name%%',  self.inpEditName.text())
+                menuFileText = menuFileText.replace('%%path%%',  folderName)
+                
+                menuFileName = self.mainApp.folderlist.Menupath + folderName + ".menu"
+                f = open(menuFileName, 'w')
+                f.write(menuFileText)
+                f.close()
+            
+            self.mainApp.showInfoPopup(self, "Your folder was successfully saved!")
+        except:
+            self.mainApp.showInfoPopup(self, "An unknown error occured while trying to save!")
     
     @pyqtSignature("")
     def on_btnAppAdd_released(self):
